const path = require('path')
const webpack = require('webpack')
const HappyPack = require('happypack')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const CopyWebpackPlugin = require('copy-webpack-plugin')
const { projectPath, resolve } = require('../utils')
const appConfig = require('../utils/get-app-config')

const config = {
  ...appConfig.webpack,
  mode: 'none',
  devtool: '#eval-source-map',
  output: {
    filename: '[name].js',
    path: `${projectPath}/public`,
  },
  module: {
    rules: [
      // {
      //   test: /\.jsx?$/,
      //   loader: 'happypack/loader',
      //   include: path.resolve(process.cwd(), 'client'),
      // },
      {
        test: /\.vue$/,
        loader: 'vue-loader',
        include: path.resolve(process.cwd(), 'client'),
      },
    ],
  },
  resolve: {
    alias: {
      'vue$': 'vue/dist/vue.esm.js',
      '@': resolve('client'),
    }
  },
  plugins: [
    new HtmlWebpackPlugin({
      filename: 'index.html',
      template: path.join(projectPath, 'index.template.ejs'),
      inject: true,
    }),
    new webpack.DllReferencePlugin({
      manifest: require(`${projectPath}/vendor_manifest.json`)
    }),
    new CopyWebpackPlugin([
      {
        from: `${projectPath}/static`,
        to: 'static',
      },
    ]),
    // new HappyPack({
    //   threads: 4,
    //   loaders: ['babel-loader?presets[]=es2015'],
    // }),
  ],
}

module.exports = config